@@ -50,7 +50,7 @@ class Exceptions:
 
 class IoTDataPlaneClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/iot-data.html#IoTDataPlane.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/iot-data.html#IoTDataPlane.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client.html)
     """
 
@@ -59,15 +59,15 @@ class IoTDataPlaneClient:
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/iot-data.html#IoTDataPlane.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/iot-data.html#IoTDataPlane.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client.html#can_paginate)
         """
 
     def delete_thing_shadow(
-        self, thingName: str, shadowName: str = None
+        self, *, thingName: str, shadowName: str = None
     ) -> DeleteThingShadowResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/iot-data.html#IoTDataPlane.Client.delete_thing_shadow)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/iot-data.html#IoTDataPlane.Client.delete_thing_shadow)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client.html#delete_thing_shadow)
         """
 
@@ -79,15 +79,15 @@ class IoTDataPlaneClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/iot-data.html#IoTDataPlane.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/iot-data.html#IoTDataPlane.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client.html#generate_presigned_url)
         """
 
     def get_thing_shadow(
-        self, thingName: str, shadowName: str = None
+        self, *, thingName: str, shadowName: str = None
     ) -> GetThingShadowResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/iot-data.html#IoTDataPlane.Client.get_thing_shadow)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/iot-data.html#IoTDataPlane.Client.get_thing_shadow)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client.html#get_thing_shadow)
         """
 
@@ -95,7 +95,7 @@ class IoTDataPlaneClient:
         self, *, thingName: str, nextToken: str = None, pageSize: int = None
     ) -> ListNamedShadowsForThingResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/iot-data.html#IoTDataPlane.Client.list_named_shadows_for_thing)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/iot-data.html#IoTDataPlane.Client.list_named_shadows_for_thing)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client.html#list_named_shadows_for_thing)
         """
 
@@ -103,7 +103,7 @@ class IoTDataPlaneClient:
         self, *, topic: str, qos: int = None, payload: Union[bytes, IO[bytes]] = None
     ) -> None:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/iot-data.html#IoTDataPlane.Client.publish)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/iot-data.html#IoTDataPlane.Client.publish)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client.html#publish)
         """
 
@@ -111,6 +111,6 @@ class IoTDataPlaneClient:
         self, *, thingName: str, payload: Union[bytes, IO[bytes]], shadowName: str = None
     ) -> UpdateThingShadowResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.92/reference/services/iot-data.html#IoTDataPlane.Client.update_thing_shadow)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.93/reference/services/iot-data.html#IoTDataPlane.Client.update_thing_shadow)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_iot_data/client.html#update_thing_shadow)
         """
